@@ -9,19 +9,22 @@ Project home: http://www.pydoubles.org
 
 import inspect
 import safeunicode
+import unittest
 
 ANY_ARG = "<___ANY___ARG___>"
 
-class UnexpectedBehavior(Exception):
+_FailureException = unittest.TestCase.failureException
+
+class UnexpectedBehavior(_FailureException):
     pass
 
-class WrongApiUsage(Exception):
+class WrongApiUsage(_FailureException):
     pass
 
-class ArgsDontMatch(Exception):
+class ArgsDontMatch(_FailureException):
     pass
 
-class ApiMismatch(Exception):
+class ApiMismatch(_FailureException):
     pass
 
 class _MatchFinder_():
