@@ -507,6 +507,14 @@ class MockTests(unittest.TestCase):
         except UnexpectedBehavior:
             pass
         
+    def test_assert_expectations_alternative(self):
+        expect_call(self.mock.hello)
+        try:
+            self.mock.assert_expectations()
+            self.fail('Not satisfied')
+        except UnexpectedBehavior:
+            pass
+        
     def test_assert_satisfied_when_it_really_is(self):
         expect_call(self.mock.hello)
         self.mock.hello()
@@ -763,6 +771,7 @@ class MatchersTests(unittest.TestCase):
         try:
           assert_that_method(self.spy.one_arg_method
             ).was_called().with_args(obj_with_fields('id = 20'))
+          self.fail('Wrong assertion, argument should be a dictionary')
         except WrongApiUsage:
             pass
 
